'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tslib_es6 = require('../../../node_modules/tslib/tslib.es6.js');
var React = require('react');
var hljs = require('highlight.js');
var cx = require('clsx');
var hooks = require('@mantine/hooks');
var core = require('@mantine/core');
var CopyIcon = require('./CopyIcon.js');
var FileIcon = require('./FileIcon.js');
var ExpandIcon = require('./ExpandIcon.js');
var CodeHighlight_module = require('./CodeHighlight.module.css.js');
var CodeHighlight_theme_module = require('./CodeHighlight.theme.module.css.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e['default'] : e; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var hljs__default = /*#__PURE__*/_interopDefaultLegacy(hljs);
var cx__default = /*#__PURE__*/_interopDefaultLegacy(cx);

const classes = Object.assign(Object.assign({}, CodeHighlight_module['default']), { root: cx__default(CodeHighlight_module['default'].root, CodeHighlight_theme_module['default'].theme) });
const defaultProps = {
    withHeader: true,
    copyLabel: 'Copy code',
    copiedLabel: 'Copied',
    maxCollapsedHeight: core.rem('8rem'),
    expandCodeLabel: 'Expand code',
    collapseCodeLabel: 'Collapse code',
};
const varsResolver = core.createVarsResolver((_, { maxCollapsedHeight }) => ({
    root: { '--ch-max-collapsed-height': core.rem(maxCollapsedHeight) },
}));
const CodeHighlightTabs = core.factory((_props, ref) => {
    const props = core.useProps('CodeHighlightTabs', defaultProps, _props);
    const { classNames, className, style, styles, unstyled, vars, children, code, defaultActiveTab, activeTab, onTabChange, withHeader, copiedLabel, copyLabel, getFileIcon, maxCollapsedHeight, expanded, defaultExpanded, onExpandedChange, expandCodeLabel, collapseCodeLabel, withExpandButton } = props, others = tslib_es6.__rest(props, ["classNames", "className", "style", "styles", "unstyled", "vars", "children", "code", "defaultActiveTab", "activeTab", "onTabChange", "withHeader", "copiedLabel", "copyLabel", "getFileIcon", "maxCollapsedHeight", "expanded", "defaultExpanded", "onExpandedChange", "expandCodeLabel", "collapseCodeLabel", "withExpandButton"]);
    const getStyles = core.useStyles({
        name: 'CodeHighlightTabs',
        props,
        classes,
        className,
        style,
        classNames,
        styles,
        unstyled,
        vars,
        varsResolver,
    });
    const [value, setValue] = hooks.useUncontrolled({
        defaultValue: defaultActiveTab,
        value: activeTab,
        finalValue: 0,
        onChange: onTabChange,
    });
    const [_expanded, setExpanded] = hooks.useUncontrolled({
        defaultValue: defaultExpanded,
        value: expanded,
        finalValue: true,
        onChange: onExpandedChange,
    });
    const nodes = Array.isArray(code) ? code : [code];
    const currentCode = nodes[value];
    const highlighted = hljs__default.highlight(currentCode.code.trim(), {
        language: currentCode.language,
    }).value;
    const files = nodes.map((node, index) => (React__default.createElement(core.UnstyledButton, Object.assign({}, getStyles('file'), { key: node.fileName, mod: { active: index === value }, onClick: () => setValue(index) }),
        React__default.createElement(FileIcon.FileIcon, { fileIcon: node.icon, getFileIcon: getFileIcon, fileName: node.fileName }),
        React__default.createElement("span", null, node.fileName))));
    return (React__default.createElement(core.Box, Object.assign({}, getStyles('root'), { ref: ref }, others, { dir: "ltr" }),
        withHeader && (React__default.createElement("div", Object.assign({}, getStyles('header')),
            React__default.createElement(core.ScrollArea, { type: "never", dir: "ltr", offsetScrollbars: false },
                React__default.createElement("div", Object.assign({}, getStyles('files')), files)),
            React__default.createElement("div", Object.assign({}, getStyles('controls')),
                withExpandButton && (React__default.createElement(core.Tooltip, { label: _expanded ? collapseCodeLabel : expandCodeLabel, fz: "sm", position: "left" },
                    React__default.createElement(core.ActionIcon, Object.assign({ onClick: () => setExpanded(!_expanded), variant: "none" }, getStyles('control')),
                        React__default.createElement(ExpandIcon.ExpandIcon, { expanded: _expanded })))),
                React__default.createElement(core.CopyButton, { value: currentCode.code.trim() }, ({ copied, copy }) => (React__default.createElement(core.Tooltip, { label: copied ? copiedLabel : copyLabel, fz: "sm", position: "left" },
                    React__default.createElement(core.ActionIcon, Object.assign({ onClick: copy, variant: "none" }, getStyles('control')),
                        React__default.createElement(CopyIcon.CopyIcon, { copied: copied })))))))),
        React__default.createElement(core.ScrollArea, { type: "auto", dir: "ltr", offsetScrollbars: false },
            React__default.createElement(core.Box, Object.assign({}, getStyles('codeWrapper'), { mod: { expanded: _expanded } }),
                React__default.createElement("pre", Object.assign({}, getStyles('pre')),
                    React__default.createElement("code", Object.assign({}, getStyles('code'), { dangerouslySetInnerHTML: { __html: highlighted } }))))),
        React__default.createElement(core.UnstyledButton, Object.assign({}, getStyles('showCodeButton'), { mod: { hidden: _expanded }, onClick: () => setExpanded(true) }), "Expand code")));
});
CodeHighlightTabs.displayName = '@mantine/core/CodeHighlightTabs';

exports.CodeHighlightTabs = CodeHighlightTabs;
//# sourceMappingURL=CodeHighlightTabs.js.map
