import { __rest } from '../../../node_modules/tslib/tslib.es6.js';
import React from 'react';
import cx from 'clsx';
import { factory, useProps, useStyles, Box, CopyButton, Tooltip, ActionIcon, ScrollArea } from '@mantine/core';
import { useHighlight } from './use-highlight.js';
import { CopyIcon } from './CopyIcon.js';
import _classes from './CodeHighlight.module.css.js';
import themeClasses from './CodeHighlight.theme.module.css.js';

const classes = Object.assign(Object.assign({}, _classes), { root: cx(_classes.root, themeClasses.theme) });
const defaultProps = {
    copyLabel: 'Copy code',
    copiedLabel: 'Copied',
    language: 'tsx',
    withCopyButton: true,
};
const CodeHighlight = factory((_props, ref) => {
    const props = useProps('CodeHighlight', defaultProps, _props);
    const { classNames, className, style, styles, unstyled, vars, children, code, copiedLabel, copyLabel, language, withCopyButton, highlightOnClient } = props, others = __rest(props, ["classNames", "className", "style", "styles", "unstyled", "vars", "children", "code", "copiedLabel", "copyLabel", "language", "withCopyButton", "highlightOnClient"]);
    const getStyles = useStyles({
        name: 'CodeHighlight',
        props,
        classes,
        className,
        style,
        classNames,
        styles,
        unstyled,
    });
    const getCodeProps = useHighlight({
        code,
        language: language,
        highlightOnClient,
    });
    return (React.createElement(Box, Object.assign({}, getStyles('root'), { ref: ref }, others, { dir: "ltr" }),
        withCopyButton && (React.createElement(CopyButton, { value: code.trim() }, ({ copied, copy }) => (React.createElement(Tooltip, { label: copied ? copiedLabel : copyLabel, fz: "sm", position: "left" },
            React.createElement(ActionIcon, Object.assign({ onClick: copy, variant: "none" }, getStyles('copy')),
                React.createElement(CopyIcon, { copied: copied })))))),
        React.createElement(ScrollArea, { type: "auto", dir: "ltr", offsetScrollbars: false },
            React.createElement("pre", Object.assign({}, getStyles('pre')),
                React.createElement("code", Object.assign({}, getStyles('code'), getCodeProps()))))));
});
CodeHighlight.displayName = '@mantine/core/CodeHighlight';

export { CodeHighlight };
//# sourceMappingURL=CodeHighlight.js.map
